<?php

namespace Drupal\text_clarity_checker\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Routing\RouteMatchInterface;

/**
 * Provides a text clarity checker.
 *
 * @Block(
 *   id = "text_clarity_checker_block",
 *   admin_label = @Translation("Text clarity checker block"),
 *   category = @Translation("Blocks")
 * )
 */
class TextClarityCheckerBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Constructor.
   */
  public function __construct(
              array               $configuration,
                                  $plugin_id,
                                  $plugin_definition,
    protected RouteMatchInterface $routeMatch,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): static {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function blockAccess(AccountInterface $account): AccessResult {
    return AccessResult::allowedIf($this->routeMatch->getRawParameter('node') !== null);
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    return [
      '#theme' => 'text_clarity_checker',
      '#attached' => [
        'library' => ['text_clarity_checker/text_clarity_checker']
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }
}
